You are viewing a plain text version of this content. The canonical link for it is here.
Posted to pluto-scm@portals.apache.org by cd...@apache.org on 2007/10/27 16:41:37 UTC

svn commit: r589118 [2/2] - in /portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet: ./ filter/

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/ResourceURL.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/ResourceURL.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/ResourceURL.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/ResourceURL.java Sat Oct 27 07:41:35 2007
@@ -84,7 +84,7 @@
 	/**
      * The URL of type <code>PAGE</code> may contain artifacts that require
      * knowledge of the state of the complete page, like
-     * <code>PortletURLs</code>, or <code>FragmentURLs</code>.
+     * <code>PortletURLs</code>.
      * <p>
      * URLs of the type <code>PAGE</code> are only cacheable on the page level
      * and can only be served from the browser cache as long as no state on the

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/StateAwareResponse.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/StateAwareResponse.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/StateAwareResponse.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/StateAwareResponse.java Sat Oct 27 07:41:35 2007
@@ -279,4 +279,19 @@
 	public WindowState getWindowState();
 
 
+	/**
+	 * Removes the specified public render parameter.
+	 * The name must reference a public render parameter defined
+	 * in the portlet deployment descriptor under the
+	 * <code>public-render-parameter</code> element with the
+	 * <code>identifier</code> mapping to the parameter name.
+	 * 
+	 * @param name			a <code>String</code> specifying 
+	 *					the name of the public render parameter to be removed
+	 *
+	 * @exception  java.lang.IllegalArgumentException 
+	 *                            if name is <code>null</code>.
+	 * @since 2.0
+	 */
+	public void removePublicRenderParameter(String name);
 }

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/ValidatorException.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/ValidatorException.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/ValidatorException.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/ValidatorException.java Sat Oct 27 07:41:35 2007
@@ -75,7 +75,7 @@
    * Constructs a new portlet validator exception.
    * Used, when the portlet needs to do one of the following:
    * <ul>
-   * <il>throw an exception 
+   * <li>throw an exception 
    * <li>include a message about the "root cause" that interfered
    *     with its normal operation
    * <li>include a description message

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ActionResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ActionResponseWrapper.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ActionResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ActionResponseWrapper.java Sat Oct 27 07:41:35 2007
@@ -76,6 +76,14 @@
 
     /**
      * The default behavior of this method is to call 
+     * <code>sendRedirect(location, renderUrlParamName)</code> on the wrapped response object.
+     */
+    public void sendRedirect(String location, String renderUrlParamName) throws IOException {
+        response.sendRedirect(location, renderUrlParamName);
+    }
+
+    /**
+     * The default behavior of this method is to call 
      * <code>setEvent(name, value)</code> on the wrapped response object.
      */
     public void setEvent(QName name, java.io.Serializable value) {
@@ -176,6 +184,14 @@
      */
 	public void setEvent(String name, java.io.Serializable value) {
 		response.setEvent(name, value);
+	}
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>removePublicRenderParameter()</code> on the wrapped response object.
+     */
+	public void removePublicRenderParameter(String name) {
+		response.removePublicRenderParameter(name);		
 	}
 
 }

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/EventResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/EventResponseWrapper.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/EventResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/EventResponseWrapper.java Sat Oct 27 07:41:35 2007
@@ -178,5 +178,13 @@
  	public void setEvent(String name, java.io.Serializable value) {
  		response.setEvent(name, value);
  	}
+ 	
+    /**
+     *  The default behavior of this method is to call 
+     * <code>removePublicRenderParameter()</code> on the wrapped response object.
+     */
+	public void removePublicRenderParameter(String name) {
+		response.removePublicRenderParameter(name);		
+	}
 
 }

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/PortletResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/PortletResponseWrapper.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/RenderResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/RenderResponseWrapper.java Sat Oct 27 07:41:35 2007
@@ -38,7 +38,10 @@
 
 import javax.portlet.CacheControl;
 import javax.portlet.PortletMode;
+import javax.portlet.PortletURL;
 import javax.portlet.RenderResponse;
+import javax.portlet.ResourceURL;
+import javax.servlet.http.Cookie;
 
 /**
  * The <code>RenderResponseWrapper</code> provides a convenient 
@@ -208,5 +211,38 @@
 
 	    	this.response = response;
     }
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>createActionURL()</code> on the wrapped response object.
+     */
+	public PortletURL createActionURL() throws IllegalStateException {
+		return response.createActionURL();
+	}
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>createRenderURL()</code> on the wrapped response object.
+     */
+	public PortletURL createRenderURL() throws IllegalStateException {
+		return response.createRenderURL();
+	}
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>createResourceURL()</code> on the wrapped response object.
+     */
+	public ResourceURL createResourceURL() throws IllegalStateException {
+		return response.createResourceURL();
+	}
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>addProperty()</code> on the wrapped response object.
+     */
+    public void addProperty(Cookie cookie) {
+        response.addProperty(cookie);
+    }
+
 
 }

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ResourceRequestWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ResourceRequestWrapper.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ResourceRequestWrapper.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ResourceRequestWrapper.java Sat Oct 27 07:41:35 2007
@@ -34,6 +34,7 @@
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
+import java.util.Map;
 
 import javax.portlet.ResourceRequest;
 
@@ -160,6 +161,14 @@
     public String getResourceID() {
         return request.getResourceID();
     }
+
+    /**
+     * The default behavior of this method is to call 
+     * <code>getPrivateRenderParameterMap()</code> on the wrapped request object.
+     */
+	public Map<String, String[]> getPrivateRenderParameterMap() {
+		return request.getPrivateParameterMap();
+	}
 
 
 }

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ResourceResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ResourceResponseWrapper.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ResourceResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/ResourceResponseWrapper.java Sat Oct 27 07:41:35 2007
@@ -36,7 +36,10 @@
 import java.util.Locale;
 
 import javax.portlet.CacheControl;
+import javax.portlet.PortletURL;
 import javax.portlet.ResourceResponse;
+import javax.portlet.ResourceURL;
+import javax.servlet.http.Cookie;
 
 /**
  * The <code>ResourceResponseWrapper</code> provides a convenient 
@@ -218,4 +221,44 @@
 	    	this.response = response;
     }
 
+    /**
+     *  The default behavior of this method is to call 
+     * <code>createActionURL()</code> on the wrapped response object.
+     */
+	public PortletURL createActionURL() throws IllegalStateException {
+		return response.createActionURL();
+	}
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>createRenderURL()</code> on the wrapped response object.
+     */
+	public PortletURL createRenderURL() throws IllegalStateException {
+		return response.createRenderURL();
+	}
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>createResourceURL()</code> on the wrapped response object.
+     */
+	public ResourceURL createResourceURL() throws IllegalStateException {
+		return response.createResourceURL();
+	}
+	
+    /**
+     *  The default behavior of this method is to call 
+     * <code>addProperty()</code> on the wrapped response object.
+     */
+    public void addProperty(Cookie cookie) {
+        response.addProperty(cookie);
+    }
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>getCacheability()</code> on the wrapped response object.
+     */
+    public String getCacheability() {
+        return response.getCacheability();
+    }
+    
 }
--- portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/PortletResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/PortletResponseWrapper.java Sat Oct 27 07:41:35 2007
@@ -31,9 +31,6 @@
 package javax.portlet.filter;
 
 import javax.portlet.PortletResponse;
-import javax.portlet.PortletURL;
-import javax.portlet.ResourceURL;
-import javax.servlet.http.Cookie;
 
 /**
  * The <code>PortletResponseWrapper</code> provides a convenient 
@@ -81,30 +78,6 @@
 
 	    /**
 	     * The default behavior of this method is to call 
-	     * <code>createActionURL()</code> on the wrapped response object.
-	     */
-	    public PortletURL createActionURL() {
-	        return response.createActionURL();
-	    }
-
-	    /**
-	     * The default behavior of this method is to call 
-	     * <code>createRenderURL()</code> on the wrapped response object.
-	     */
-	    public PortletURL createRenderURL() {
-	        return response.createRenderURL();
-	    }
-
-	    /**
-	     * The default behavior of this method is to call 
-	     * <code>createResourceURL</code> on the wrapped response object.
-	     */
-	    public ResourceURL createResourceURL() {
-	        return response.createResourceURL();
-	    }
-
-	    /**
-	     * The default behavior of this method is to call 
 	     * <code>encodeURL(path)</code> on the wrapped response object.
 	     */
 	    public String encodeURL(String path) {
@@ -153,16 +126,16 @@
 	     *  The default behavior of this method is to call 
 	     * <code>addProperty()</code> on the wrapped response object.
 	     */
-	    public void addProperty(Cookie cookie) {
-	        response.addProperty(cookie);
+	    public void addProperty(String key, org.w3c.dom.Element element) {
+	        response.addProperty(key, element);
 	    }
 
 	    /**
 	     *  The default behavior of this method is to call 
 	     * <code>addProperty()</code> on the wrapped response object.
 	     */
-	    public void addProperty(String key, org.w3c.dom.Element element) {
-	        response.addProperty(key, element);
+	    public org.w3c.dom.Element createElement(String tagName) {
+	        return response.createElement(tagName);
 	    }
 
 }
@@ -153,16 +126,16 @@
 	    /**
 	     *  The default behavior of this method is to call 
-	     * <code>addProperty()</code> on the wrapped response object.
+	     * <code>createElement()</code> on the wrapped response object.
 	     */

Modified: portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/RenderResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-trunk-merge/portlet2-api/src/main/java/javax/portlet/filter/RenderResponseWrapper.java?rev=589118&r1=589117&r2=589118&view=diff
==============================================================================